@@ -1,5 +1,5 @@
 """
-NL2BR Extension
+`NL2BR` Extension
 ===============
 
 A Python-Markdown extension to treat newlines as hard breaks; like
@@ -8,7 +8,7 @@ GitHub-flavored Markdown does.
 See <https://Python-Markdown.github.io/extensions/nl2br>
 for documentation.
 
-Oringinal code Copyright 2011 [Brian Neal](https://deathofagremmie.com/)
+Original code Copyright 2011 [Brian Neal](https://deathofagremmie.com/)
 
 All changes Copyright 2011-2014 The Python Markdown Project
 
